about summary refs log tree commit diff
path: root/src/bootstrap
diff options
context:
space:
mode:
authorCorey Farwell <coreyf@rwell.org>2017-04-25 23:05:54 -0400
committerGitHub <noreply@github.com>2017-04-25 23:05:54 -0400
commit27fbe8cbca09b9908288faebb59ea34a2c89bc8e (patch)
tree6ad7713bcb5bb319dffb27e4f74c99516365bec5 /src/bootstrap
parent7e7114fe2e26c5ccd6ebbd5686410b61a47820dc (diff)
parent70e673952ee7544576e2912efe9735bc4617e447 (diff)
downloadrust-27fbe8cbca09b9908288faebb59ea34a2c89bc8e.tar.gz
rust-27fbe8cbca09b9908288faebb59ea34a2c89bc8e.zip
Rollup merge of #39983 - AndrewGaspar:rust-windbg, r=brson
Adds rust-windbg.cmd script

Adds rust-gdb/rust-lldb equivalent for windbg that loads the Rust .natvis files on start.

This change modifies the bootstrap code to add rust-windbg to bin and the .natvis files to lib/rustlib/etc.

Example usage from cmd or PowerShell:
```
rust-windbg -c "bu rs_f442289d74765418!rs::main;g" target\debug\rs.exe
```
Diffstat (limited to 'src/bootstrap')
-rw-r--r--src/bootstrap/dist.rs7
1 files changed, 6 insertions, 1 deletions
diff --git a/src/bootstrap/dist.rs b/src/bootstrap/dist.rs
index 4328c4e3f1d..ada8d4df604 100644
--- a/src/bootstrap/dist.rs
+++ b/src/bootstrap/dist.rs
@@ -254,7 +254,12 @@ pub fn debugger_scripts(build: &Build,
         install(&build.src.join("src/etc/").join(file), &dst, 0o644);
     };
     if host.contains("windows-msvc") {
-        // no debugger scripts
+        // windbg debugger scripts
+        install(&build.src.join("src/etc/rust-windbg.cmd"), &sysroot.join("bin"),
+            0o755);
+
+        cp_debugger_script("natvis/libcore.natvis");
+        cp_debugger_script("natvis/libcollections.natvis");
     } else {
         cp_debugger_script("debugger_pretty_printers_common.py");